# aiogossip

AsyncIO implementation of Gossip protocol

# Reference

-  [Gossip protocol](https://en.wikipedia.org/wiki/Gossip_protocol)
-  [Gossip simulator](https://flopezluis.github.io/gossip-simulator/)
